@@ -419,7 +419,7 @@ class Sequential():
         else:
             raise RuntimeError("model not trained")
             
-    def get_parameters(self):
+    def save_parameters(self):
         if self.__is_trained__ == True:
             import pickle
             parameters = {"weights": None, "biases": None}
@@ -440,7 +440,7 @@ class Sequential():
         else:
             raise RuntimeError("model not trained")
         
-    def set_parameters(self, parameters = None):
+    def load_parameters(self, parameters = None):
         if type(parameters) == dict or parameters == None:
             import pickle
             if parameters == None:
